# <img src='https://0000.us/klatchat/app/files/neon_images/icons/neon_skill.png' card_color="#FF8600" width="50" style="vertical-align:bottom">Speed Test

## Summary

Skill used to test your internet speed

## Description

This skill uses speedtest.net to check your internet speed

## Examples

Ask Neon to start a test:

- "Run a speed test."
- "How fast is my internet?"

## Contact Support

Use the [link](https://neongecko.com/ContactUs) or [submit an issue on GitHub](https://help.github.com/en/articles/creating-an-issue)

## Category
**Daily**
Productivity

## Credits
[NeonDaniel](https://github.com/NeonDaniel)
[NeonGeckoCom](https://github.com/NeonGeckoCom)
[reginaneon](https://github.com/reginaneon)

## Tags
#NeonGecko Original
#NeonAI
#Internet
#Utilities